# Reaktorfysik med python

This repo contains the material developed for an introductory reactor physics course given at Uppsala University (further info on the course [here](https://www.uu.se/utbildning/utbildningar/selma/kurser/?kKod=1FA456&lasar=21%2F22&typ=1)). 

The course gives an overview of

- Basic nuclear physics relevant to reactor applications (radioactive decay, nuclear fission, neutron-nucleus collisions).
- Slowing down of neutrons and the neutron cycle
- Neutron transport and neutron diffusion
- Reactor kinetics, safety relevant feedbacks in reactors.
- Fuel evolution during irradiation
- Monte Carlo particle transport methods
- Python programming and data analysis

The course contains
- 11 lectures (which cover the material in the lecture notes)
- 11 computer labs
    - Students receive Jupyter notebook files
    - Students complete the notebook based on the instructions
- 3 set of Home Assignments

The content of this repo:
- latexsrc: contains the source code for the lecture notes and figures
- Datalabs: contains the jupyter notebooks and additional files for the datalabs
- HomeAssignments: contains the jupyter notebooks for the home assignments
- LectureFigures: contains a jupyter notebook with the source code of the figures in the lecture note, and some additional data files.
- RFP_lecturenotes.pdf: the lecture note

We do not wish to share the solutions to the exercises publicly, however if you are an educator who would require the solutions, please contact us. Please notice that the python source code is available for all the figures. Soon it is going to be shared in the form of jupyter notebooks. If you would like to access them before, please contact us.

## Dependencies

The datalabs are based on Jupyter notebooks, and make use of the mainstream python libraries. The student is adviced to use either Google's Colab or install an Anaconda distribution. Nevertheless, some datalabs require openMC to be [installed](https://docs.openmc.org/en/stable/quickinstall.html).

Packages used:
- numpy
- scipy
- matplotlib
- pandas
- openMC python API

We have prepared a Virtual Ubuntu with the required software pre-installed. If you would like to use it, please contact us.

## Contribution

If you find any mistake in the Lecture Notes or the datalab material, please contact us.

## Contact

Please write a mail at the address published at [here](https://katalog.uu.se/profile/?id=N16-2113)
